]> Shamusworld >> Repos - rmac/blobdiff - token.h
Fix for bug #51. Apparently 10 tokens weren't enough for modern programming!
[rmac] / token.h
diff --git a/token.h b/token.h
index 2daf6445c1426113d5ec60de3807ea8e969c457c..3d3ea22c017b4f1a5c7fc144c1e83818a6d5ed52 100644 (file)
--- a/token.h
+++ b/token.h
@@ -3,14 +3,13 @@
 // TOKEN.H - Token Handling
 // Copyright (C) 199x Landon Dyer, 2011 Reboot and Friends
 // RMAC derived from MADMAC v1.07 Written by Landon Dyer, 1986
-// Source Utilised with the Kind Permission of Landon Dyer
+// Source utilised with the kind permission of Landon Dyer
 //
 
 #ifndef __TOKEN_H__
 #define __TOKEN_H__
 
 #include "rmac.h"
-//#include "risca.h"
 
 // Include Files and Macros
 #define SRC_IFILE       0                                      // Input source is IFILE
@@ -112,8 +111,8 @@ IFILE {
 
 #define TOKENSTREAM struct _tokenstream
 TOKENSTREAM {
-       TOKEN token[10];                // 10 ought to be enough for anybody
-       char * string[10];              // same for attached strings
+       TOKEN token[32];                // 32 ought to be enough for anybody (including XiA!)
+       char * string[32];              // same for attached strings
 };
 
 // Information about a macro invocation
@@ -155,9 +154,9 @@ extern char * string[];
 
 // Prototypes
 int include(int, char *);
-void init_token(void);
-//void setfnum(WORD);
-int tokln(void);
+void InitTokenizer(void);
+void SetFilenameForErrorReporting(void);
+int TokenizeLine(void);
 int fpop(void);
 int d_goto(WORD);
 //int d_goto(void);